/**
 * Lottier for Elementor
 * Lottie animations in just a few clicks without writing a single line of code.
 * Exclusively on https://1.envato.market/lottier-elementor
 *
 * @encoding        UTF-8
 * @version         1.0.8
 * @copyright       (C) 2018 - 2020 Merkulove ( https://merkulov.design/ ). All rights reserved.
 * @license         Envato License https://1.envato.market/KYbje
 * @contributors    Vitaliy Nemirovskiy (nemirovskiyvitaliy@gmail.com), Dmitry Merkulov (dmitry@merkulov.design)
 * @support         help@merkulov.design
 * @license         Envato License https://1.envato.market/KYbje
 **/

document.addEventListener('DOMContentLoaded', function () {

    class init extends elementorModules.frontend.handlers.Base {

        lottierCode( animation_speed, play_animation, play_mode, animation_loop, show_controls ){

            const lottierItem = document.querySelector( "#mdp-lottier-" + this.getID() );

            if( play_animation === 'autoplay' ){ lottierItem.autoplay = true; lottierItem.play(); }
            if( play_animation === 'hover' || play_animation === 'section' ){ lottierItem.hover = true; }
            lottierItem.mode = play_mode;
            lottierItem.controls = show_controls;
            lottierItem.loop = animation_loop;
            lottierItem.speed = animation_speed.size;

            if( play_animation === 'section' ){
                let boxLink = document.querySelector( "#mdp-lottier-box-" + this.getID() );

                boxLink.addEventListener("mouseover", function () { lottierItem.play(); });

                boxLink.addEventListener("mouseout", function () { lottierItem.pause(); });

            }

            if( play_animation === 'click' ){
                let startPlay = 0;

                lottierItem.addEventListener("click", function () {
                    if (startPlay === 0) { lottierItem.play(); startPlay = 1;
                    } else { lottierItem.pause(); startPlay = 0; }
                });
            }

        }

        bindEvents() {
            let animation_speed   = this.getElementSettings( 'animation_speed' );
            let play_animation   = this.getElementSettings( 'play_animation' );
            let play_mode   = this.getElementSettings( 'play_mode' );
            let animation_loop = this.getElementSettings( 'animation_loop' ) === 'yes' ? true : false;
            let show_controls = this.getElementSettings( 'show_controls' ) === 'yes' ? true : false;

            this.lottierCode( animation_speed, play_animation, play_mode, animation_loop, show_controls );

        }
    }

    jQuery( window ).on( 'elementor/frontend/init', () => {
        const addHandler = ( $element ) => {
            elementorFrontend.elementsHandler.addHandler( init, {
                $element,
            } );
        };

        elementorFrontend.hooks.addAction( 'frontend/element_ready/mdp-lottier-elementor.default', addHandler );
    } );

});
